@@ -23,10 +23,13 @@ def load_chart(chart_type, series, container, kw_extra, *args, **kwargs):
         * ``container`` - Chart holder in html page.
 
     **kw_extra settings**::
-        * ``x_is_date`` - if x-axis is in date format
-        * ``x_axis_format`` - display x-axis date in various format ie "%d %b %Y"
-        * ``tag_script_js`` - if show the javascript tag <script>
+        * ``x_is_date`` - if enabled the x-axis will be display as date format
+        * ``x_axis_format`` - set the x-axis date format, ie. "%d %b %Y"
+        * ``tag_script_js`` - if enabled it will add the javascript tag '<script>'
+        * ``jquery_on_ready`` - if enabled it will load the javascript only when page is loaded
+            this will use jquery library, so make sure to add jquery to the template.
         * ``color_category`` - Define color category (eg. category10, category20, category20c)
+        * ``chart_attr`` - Custom chart attributes
     """
     if not chart_type:
         return False
@@ -39,14 +42,19 @@ def load_chart(chart_type, series, container, kw_extra, *args, **kwargs):
         kw_extra['color_category'] = "category20"
     if not 'tag_script_js' in kw_extra:
         kw_extra['tag_script_js'] = True
+    if not 'chart_attr' in kw_extra:
+        kw_extra['chart_attr'] = {}
     # set the container name
-    kw_extra['name'] = container
+    kw_extra['name'] = unicode(container)
 
     # Build chart
     chart = eval(chart_type)(**kw_extra)
 
     xdata = series['x']
-    y_axis_list = [d for d in series.keys() if 'y' in d]
+    y_axis_list = [k for k in series.keys() if k.startswith('y')]
+    if len(y_axis_list) > 1:
+        # Ensure numeric sorting
+        y_axis_list = sorted(y_axis_list, key=lambda x: int(x[1:]))
 
     for key in y_axis_list:
         ydata = series[key]
@@ -54,29 +62,18 @@ def load_chart(chart_type, series, container, kw_extra, *args, **kwargs):
 
         name = series['name' + axis_no] if series.get('name' + axis_no) else None
         extra = series['extra' + axis_no] if series.get('extra' + axis_no) else {}
+        kwargs = series['kwargs' + axis_no] if series.get('kwargs' + axis_no) else {}
 
-        if chart_type == 'linePlusBarChart' or chart_type == 'linePlusBarWithFocusChart':
-            if key == 'y1':
-                kwargs = series['kwargs1']
-                chart.add_serie(name=name, y=ydata, x=xdata, extra=extra, **kwargs)
-            else:
-                chart.add_serie(name=name, y=ydata, x=xdata, extra=extra)
-        elif chart_type == 'scatterChart':
-            # get digit
-            kwargs = series['kwargs' + axis_no]
-            chart.add_serie(name=name, y=ydata, x=xdata, extra=extra, **kwargs)
-        elif chart_type == 'pieChart':
-            chart.add_serie(y=ydata, x=xdata, extra=extra)
-        else:
-            chart.add_serie(name=name, y=ydata, x=xdata, extra=extra)
+        chart.add_serie(name=name, y=ydata, x=xdata, extra=extra, **kwargs)
 
-    chart.buildhtml()
+    chart.display_container = False
+    chart.buildcontent()
 
-    html_string = chart.jschart + '\n'
+    html_string = chart.htmlcontent + '\n'
     return mark_safe(html_string)
 
 
-@register.simple_tag(name='include_container')
+@register.simple_tag
 def include_container(include_container, height=400, width=600):
     """
     Include the html for the chart container and css for nvd3
@@ -94,7 +91,7 @@ def include_container(include_container, height=400, width=600):
         * ``width`` - Chart width
     """
     chart = NVD3Chart()
-    chart.name = include_container
+    chart.name = unicode(include_container)
     chart.set_graph_height(height)
     chart.set_graph_width(width)
     chart.buildcontainer()
@@ -102,7 +99,7 @@ def include_container(include_container, height=400, width=600):
     return mark_safe(chart.container + '\n')
 
 
-@register.simple_tag(name='include_chart_jscss')
+@register.simple_tag
 def include_chart_jscss(static_dir=''):
     """
     Include the html for the chart container and css for nvd3
